@@ -1,6 +1,6 @@
 package SPVM::File::Path;
 
-our $VERSION = "0.013";
+our $VERSION = "0.014";
 
 1;
 
@@ -50,15 +50,23 @@ The same as L</"mkpath"> method.
 
 =head2 rmtree
 
-C<static method rmtree : int ($path : string);>
+C<static method rmtree : int ($path : string, $options : object[] = undef);>
 
 Removes a directory $path that contain files or directories within them.
 
+Options:
+
+=over 2
+
+=item * keep_root : Int = 0
+
+=back
+
 See Perl's L<File::Path/"rmtree"> for details.
 
 =head2 remove_tree
 
-C<static method remove_tree : int ($path : string);>
+C<static method remove_tree : int ($path : string, $options : object[] = undef);>
 
 The same as L</"rmtree"> method.
 
